### Sample Optimization
Cardboard Box | ParametricSoln v0.2.1
by: Charlie Taylor | March 06, 2023

PRIOR TO MAXIMIZE OPTIMIZATION
    ParametricSoln: Cardboard Box

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             L           12            1           20 Length of Cardboard  (in)
        WoverL            1         0.05            1 Width/Length of Cardboard
        HoverW          0.1         0.05         0.45 Height/Width of Box

     Figure of Merit: Box Volume (Volume) = 110.592 cuin <== Maximize

    ========================== OPTIMIZATION CONSTRAINTS =========================
          name         value        minimum   maximum
       boxMass       0.3456 ------------          0.5 Box Mass
    ============================================================================

AFTER MAXIMIZE OPTIMIZATION
    ParametricSoln: Cardboard Box

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             L      16.3299            1           20 Length of Cardboard  (in)
        WoverL     0.999999         0.05            1 Width/Length of Cardboard
        HoverW         0.25         0.05         0.45 Height/Width of Box

     Figure of Merit: Box Volume (Volume) = 272.166 cuin <== Maximize

    ========================== OPTIMIZATION CONSTRAINTS =========================
          name         value        minimum   maximum
       boxMass          0.5 ------------          0.5 Box Mass
    ============================================================================

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
L | 16.3299 | in | Length of Cardboard (in)
WoverL | 0.999999 |  | Width/Length of Cardboard
HoverW | 0.25 |  | Height/Width of Box
thk | 0.1 | in | Thickness of Cardboard (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 272.166 | cuin | Box Volume (cuin) | --- | ---
boxMass | 0.5 | lbm | Box Mass (lbm) | --- | <0.5

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
L | 16.3299 | in | Length of Cardboard (in)
WoverL | 0.999999 |  | Width/Length of Cardboard
HoverW | 0.25 |  | Height/Width of Box
thk | 0.1 | in | Thickness of Cardboard (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 272.166 | cuin | Box Volume (cuin) | --- | ---
boxMass | 0.5 | lbm | Box Mass (lbm) | --- | <0.5

Design Variables (nominal values)
Name | Value | Units | Description
WoverL | 0.999999 |  | Width/Length of Cardboard
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
L | 16.3299 | in | Length of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
L | 16.3299 | in | Length of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
WoverL | 0.999999 |  | Width/Length of Cardboard
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
L | 16.3299 | in | Length of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
WoverL | 0.999999 |  | Width/Length of Cardboard
HoverW | 0.25 |  | Height/Width of Box
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
L | 16.3299 | in | Length of Cardboard (in)
WoverL | 0.999999 |  | Width/Length of Cardboard
HoverW | 0.25 |  | Height/Width of Box
thk | 0.1 | in | Thickness of Cardboard (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 272.166 | cuin | Box Volume (cuin) | --- | ---
boxMass | 0.5 | lbm | Box Mass (lbm) | --- | <0.5

    Parametric Solutions
    parasol v0.2.1
    contact: C. Taylor, cet@appliedpython.com